┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/panels/folders/folderspanel.cpp
diff options
context:
space:
mode:
authorMichael Heidelbach <[email protected]>2018-01-14 10:53:11 -0700
committerNathaniel Graham <[email protected]>2018-01-14 10:54:46 -0700
commit3cb3d58fbf0a5d3736579ad7a52a2a46ab9c1d29 (patch)
tree4864823d98692d524390b8839b5e93f0391e1072 /src/panels/folders/folderspanel.cpp
parent65c0997164bd6f770c4286f7be83bcd2d3d145bd (diff)
folderspanel context-menu option "Limit to Home Directory" should be always visible
Summary: Only by chance I discovered that this option is visible but only when inside home. Before that I always edited dolphinrc to reenable it. I think it's less confusing to always show it but toggle its enabled state Test Plan: compile and run show folderspanel context-menu in different places Reviewers: #dolphin, emmanuelp, ngraham Reviewed By: #dolphin, ngraham Subscribers: elvisangelaccio Tags: #dolphin, #kde_applications Differential Revision: https://phabricator.kde.org/D9662
Diffstat (limited to 'src/panels/folders/folderspanel.cpp')
-rw-r--r--src/panels/folders/folderspanel.cpp28
1 files changed, 18 insertions, 10 deletions
diff --git a/src/panels/folders/folderspanel.cpp b/src/panels/folders/folderspanel.cpp
index eef27ce47..add7f692b 100644
--- a/src/panels/folders/folderspanel.cpp
+++ b/src/panels/folders/folderspanel.cpp
@@ -137,7 +137,7 @@ bool FoldersPanel::urlChanged()
void FoldersPanel::reloadTree()
{
if (m_controller) {
- loadTree(url());
+ loadTree(url(), true);
}
}
@@ -316,34 +316,42 @@ void FoldersPanel::startFadeInAnimation()
anim->setDuration(200);
}
-void FoldersPanel::loadTree(const QUrl& url)
+void FoldersPanel::loadTree(const QUrl& url, bool allowJumpHome)
{
Q_ASSERT(m_controller);
m_updateCurrentItem = false;
+ bool jumpHome = false;
QUrl baseUrl;
- if (url.isLocalFile()) {
- const bool isInHomeFolder = Dolphin::homeUrl().isParentOf(url) || (Dolphin::homeUrl() == url);
- if (FoldersPanelSettings::limitFoldersPanelToHome() && isInHomeFolder) {
+ if (!url.isLocalFile()) {
+ // Clear the path for non-local URLs and use it as base
+ baseUrl = url;
+ baseUrl.setPath(QString('/'));
+ } else if (Dolphin::homeUrl().isParentOf(url) || (Dolphin::homeUrl() == url)) {
+ if (FoldersPanelSettings::limitFoldersPanelToHome() ) {
baseUrl = Dolphin::homeUrl();
} else {
// Use the root directory as base for local URLs (#150941)
baseUrl = QUrl::fromLocalFile(QDir::rootPath());
}
+ } else if (FoldersPanelSettings::limitFoldersPanelToHome() && allowJumpHome) {
+ baseUrl = Dolphin::homeUrl();
+ jumpHome = true;
} else {
- // Clear the path for non-local URLs and use it as base
- baseUrl = url;
- baseUrl.setPath(QString('/'));
+ // Use the root directory as base for local URLs (#150941)
+ baseUrl = QUrl::fromLocalFile(QDir::rootPath());
}
- if (m_model->directory() != baseUrl) {
+ if (m_model->directory() != baseUrl && !jumpHome) {
m_updateCurrentItem = true;
m_model->refreshDirectory(baseUrl);
}
const int index = m_model->index(url);
- if (index >= 0) {
+ if (jumpHome == true) {
+ emit folderActivated(baseUrl);
+ } else if (index >= 0) {
updateCurrentItem(index);
} else if (url == baseUrl) {
// clear the selection when visiting the base url